package com.ruoyi.web.controller.commodity;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.commodity.domain.DoumuCommodityInfo;
import com.ruoyi.commodity.service.IDoumuCommodityInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 商品信息Controller
 * 
 * @author boman
 * @date 2024-01-26
 */
@RestController
@RequestMapping("/commodity/info")
public class DoumuCommodityInfoController extends BaseController
{
    @Autowired
    private IDoumuCommodityInfoService doumuCommodityInfoService;

    /**
     * 查询商品信息列表
     */
    @PreAuthorize("@ss.hasPermi('commodity:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(DoumuCommodityInfo doumuCommodityInfo)
    {
        startPage();
        List<DoumuCommodityInfo> list = doumuCommodityInfoService.selectDoumuCommodityInfoList(doumuCommodityInfo);
        return getDataTable(list);
    }
    /**
     * 查询商品信息列表
     */
    @GetMapping("/listNoPage")
    public TableDataInfo listNoPage(DoumuCommodityInfo doumuCommodityInfo)
    {
        List<DoumuCommodityInfo> list = doumuCommodityInfoService.selectDoumuCommodityInfoList(doumuCommodityInfo);
        return getDataTable(list);
    }

    /**
     * 导出商品信息列表
     */
    @PreAuthorize("@ss.hasPermi('commodity:info:export')")
    @Log(title = "商品信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DoumuCommodityInfo doumuCommodityInfo)
    {
        List<DoumuCommodityInfo> list = doumuCommodityInfoService.selectDoumuCommodityInfoList(doumuCommodityInfo);
        ExcelUtil<DoumuCommodityInfo> util = new ExcelUtil<DoumuCommodityInfo>(DoumuCommodityInfo.class);
        util.exportExcel(response, list, "商品信息数据");
    }

    /**
     * 获取商品信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('commodity:info:query')")
    @GetMapping(value = "/{commodityId}")
    public AjaxResult getInfo(@PathVariable("commodityId") Long commodityId)
    {
        return success(doumuCommodityInfoService.selectDoumuCommodityInfoByCommodityId(commodityId));
    }

    /**
     * 新增商品信息
     */
    @PreAuthorize("@ss.hasPermi('commodity:info:add')")
    @Log(title = "商品信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DoumuCommodityInfo doumuCommodityInfo)
    {
        return toAjax(doumuCommodityInfoService.insertDoumuCommodityInfo(doumuCommodityInfo));
    }

    /**
     * 修改商品信息
     */
    @PreAuthorize("@ss.hasPermi('commodity:info:edit')")
    @Log(title = "商品信息", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody DoumuCommodityInfo doumuCommodityInfo)
    {
        return toAjax(doumuCommodityInfoService.updateDoumuCommodityInfo(doumuCommodityInfo));
    }

    /**
     * 删除商品信息
     */
    @PreAuthorize("@ss.hasPermi('commodity:info:remove')")
    @Log(title = "商品信息", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{commodityIds}")
    public AjaxResult remove(@PathVariable Long[] commodityIds)
    {
        return toAjax(doumuCommodityInfoService.deleteDoumuCommodityInfoByCommodityIds(commodityIds));
    }
}
