package com.ruoyi.commodity.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.commodity.mapper.DoumuCommodityInfoMapper;
import com.ruoyi.commodity.domain.DoumuCommodityInfo;
import com.ruoyi.commodity.service.IDoumuCommodityInfoService;

/**
 * 商品信息Service业务层处理
 * 
 * @author boman
 * @date 2024-01-26
 */
@Service
public class DoumuCommodityInfoServiceImpl implements IDoumuCommodityInfoService 
{
    @Autowired
    private DoumuCommodityInfoMapper doumuCommodityInfoMapper;

    /**
     * 查询商品信息
     * 
     * @param commodityId 商品信息主键
     * @return 商品信息
     */
    @Override
    public DoumuCommodityInfo selectDoumuCommodityInfoByCommodityId(Long commodityId)
    {
        return doumuCommodityInfoMapper.selectDoumuCommodityInfoByCommodityId(commodityId);
    }

    /**
     * 查询商品信息列表
     * 
     * @param doumuCommodityInfo 商品信息
     * @return 商品信息
     */
    @Override
    public List<DoumuCommodityInfo> selectDoumuCommodityInfoList(DoumuCommodityInfo doumuCommodityInfo)
    {
        return doumuCommodityInfoMapper.selectDoumuCommodityInfoList(doumuCommodityInfo);
    }

    /**
     * 新增商品信息
     * 
     * @param doumuCommodityInfo 商品信息
     * @return 结果
     */
    @Override
    public int insertDoumuCommodityInfo(DoumuCommodityInfo doumuCommodityInfo)
    {
        doumuCommodityInfo.setCreateTime(DateUtils.getNowDate());
        return doumuCommodityInfoMapper.insertDoumuCommodityInfo(doumuCommodityInfo);
    }

    /**
     * 修改商品信息
     * 
     * @param doumuCommodityInfo 商品信息
     * @return 结果
     */
    @Override
    public int updateDoumuCommodityInfo(DoumuCommodityInfo doumuCommodityInfo)
    {
        doumuCommodityInfo.setUpdateTime(DateUtils.getNowDate());
        return doumuCommodityInfoMapper.updateDoumuCommodityInfo(doumuCommodityInfo);
    }

    /**
     * 批量删除商品信息
     * 
     * @param commodityIds 需要删除的商品信息主键
     * @return 结果
     */
    @Override
    public int deleteDoumuCommodityInfoByCommodityIds(Long[] commodityIds)
    {
        return doumuCommodityInfoMapper.deleteDoumuCommodityInfoByCommodityIds(commodityIds);
    }

    /**
     * 删除商品信息信息
     * 
     * @param commodityId 商品信息主键
     * @return 结果
     */
    @Override
    public int deleteDoumuCommodityInfoByCommodityId(Long commodityId)
    {
        return doumuCommodityInfoMapper.deleteDoumuCommodityInfoByCommodityId(commodityId);
    }
}
