package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.ChinaArea;
import com.ruoyi.system.mapper.ChinaAreaMapper;
import com.ruoyi.system.service.IChinaAreaService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * 中国行政规划Service业务层处理
 * 
 * @author boman
 * @date 2023-03-28
 */
@Service
public class ChinaAreaServiceImpl implements IChinaAreaService
{
    @Autowired
    private ChinaAreaMapper chinaAreaMapper;

    /**
     * 查询中国行政规划
     * 
     * @param areaId 中国行政规划主键
     * @return 中国行政规划
     */
    @Override
    public ChinaArea selectChinaAreaByAreaId(String areaId)
    {
        return chinaAreaMapper.selectChinaAreaByAreaId(areaId);
    }

    /**
     * 查询中国行政规划列表
     * 
     * @param chinaArea 中国行政规划
     * @return 中国行政规划
     */
    @Override
    public List<ChinaArea> selectChinaAreaList(ChinaArea chinaArea)
    {
        return chinaAreaMapper.selectChinaAreaList(chinaArea);
    }

    /**
     * 新增中国行政规划
     * 
     * @param chinaArea 中国行政规划
     * @return 结果
     */
    @Override
    public int insertChinaArea(ChinaArea chinaArea)
    {
        return chinaAreaMapper.insertChinaArea(chinaArea);
    }

    /**
     * 修改中国行政规划
     * 
     * @param chinaArea 中国行政规划
     * @return 结果
     */
    @Override
    public int updateChinaArea(ChinaArea chinaArea)
    {
        return chinaAreaMapper.updateChinaArea(chinaArea);
    }

    /**
     * 批量删除中国行政规划
     * 
     * @param areaIds 需要删除的中国行政规划主键
     * @return 结果
     */
    @Override
    public int deleteChinaAreaByAreaIds(String[] areaIds)
    {
        return chinaAreaMapper.deleteChinaAreaByAreaIds(areaIds);
    }

    /**
     * 删除中国行政规划信息
     * 
     * @param areaId 中国行政规划主键
     * @return 结果
     */
    @Override
    public int deleteChinaAreaByAreaId(String areaId)
    {
        return chinaAreaMapper.deleteChinaAreaByAreaId(areaId);
    }

    /**
     * 获取行政规划
     * @param pid
     * @return
     */
    @Override
    public AjaxResult area(String pid) {
        List<ChinaArea> chinaAreas = chinaAreaMapper.selectChinaAreaByPId(pid);
        return AjaxResult.success(chinaAreas);
    }
}
