package com.ruoyi.system.service.impl;

import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import com.ruoyi.common.constant.HttpStatus;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.DoumuEvaluate;
import com.ruoyi.system.domain.DoumuProductFj;
import com.ruoyi.system.domain.DoumuProductHistory;
import com.ruoyi.system.domain.vo.DoumuProductInfoVo;
import com.ruoyi.system.mapper.*;
import lombok.SneakyThrows;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.domain.DoumuProductInfo;
import com.ruoyi.system.service.IDoumuProductInfoService;
import org.springframework.transaction.annotation.Transactional;
import utils.ClassUtils;

/**
 * 痘姆古陶信息Service业务层处理
 *
 * @author boman
 * @date 2024-01-16
 */
@Service
public class DoumuProductInfoServiceImpl implements IDoumuProductInfoService
{
    @Autowired
    private DoumuProductInfoMapper doumuProductInfoMapper;

    @Autowired
    private DoumuProductFjMapper doumuProductFjMapper;

    @Autowired
    private SysDictDataMapper dictDataMapper;

    @Autowired
    private DoumuEvaluateMapper doumuEvaluateMapper;

    @Autowired
    private DoumuProductHistoryMapper doumuProductHistoryMapper;

    /**
     * 查询痘姆古陶信息
     *
     * @param productId 痘姆古陶信息主键
     * @return 痘姆古陶信息
     */
    @Override
    public DoumuProductInfo selectDoumuProductInfoByProductId(Long productId)
    {
        DoumuProductInfo doumuProductInfo = doumuProductInfoMapper.selectDoumuProductInfoByProductId(productId);
        //查询附件
        DoumuProductFj doumuProductFj = new DoumuProductFj();
        doumuProductFj.setProductId(productId);
        List<DoumuProductFj> fjList = doumuProductFjMapper.selectDoumuProductFjList(doumuProductFj);
        doumuProductInfo.setFjList(fjList);
        //查询评价信息
        DoumuEvaluate  doumuEvaluate = doumuEvaluateMapper.selectDoumuEvaluateByProductId(productId);
        doumuProductInfo.setDoumuEvaluate(doumuEvaluate);
        return doumuProductInfo;
    }

    /**
     * 查询痘姆古陶信息列表
     *
     * @param doumuProductInfo 痘姆古陶信息
     * @return 痘姆古陶信息
     */
    @Override
    public List<DoumuProductInfo> selectDoumuProductInfoList(DoumuProductInfo doumuProductInfo)
    {
        List<DoumuProductInfo> doumuProductInfoList = doumuProductInfoMapper.selectDoumuProductInfoList(doumuProductInfo);
        for (DoumuProductInfo productInfo : doumuProductInfoList) {
            //查询附件
            DoumuProductFj doumuProductFj = new DoumuProductFj();
            doumuProductFj.setProductId(productInfo.getProductId());
            doumuProductFj.setModule("1");
            List<DoumuProductFj> fjList = doumuProductFjMapper.selectDoumuProductFjList(doumuProductFj);
            productInfo.setFjList(fjList);
        }
        return doumuProductInfoList;
    }

    /**
     * 新增痘姆古陶信息
     *
     * @param doumuProductInfo 痘姆古陶信息
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult insertDoumuProductInfo(DoumuProductInfo doumuProductInfo)
    {
        doumuProductInfo.setOrderNumber("DMGT"+System.currentTimeMillis());
        doumuProductInfo.setCreateTime(DateUtils.getNowDate());
        doumuProductInfo.setClosedTime(DateUtils.toDate(LocalDateTime.now().plusMinutes(15)));
        int rows = doumuProductInfoMapper.insertDoumuProductInfo(doumuProductInfo);

        //保存附件
        List<DoumuProductFj> fjList = doumuProductInfo.getFjList();
        if(fjList!=null && fjList.size()>0){
            for (DoumuProductFj doumuProductFj : fjList) {
                doumuProductFj.setProductId(doumuProductInfo.getProductId());
                doumuProductFj.setModule("1");
                doumuProductFjMapper.insertDoumuProductFj(doumuProductFj);
            }
        }
        return rows > 0 ? AjaxResult.success(doumuProductInfo) : AjaxResult.error();
    }

    /**
     * 修改痘姆古陶信息
     *
     * @param doumuProductInfo 痘姆古陶信息
     * @return 结果
     */
    @Override
    @SneakyThrows
    @Transactional(rollbackFor = Exception.class)
    public int updateDoumuProductInfo(DoumuProductInfo doumuProductInfo)
    {
        doumuProductInfo.setUpdateTime(DateUtils.getNowDate());
        //先删除附件
        doumuProductFjMapper.deleteDoumuProductFjByProductId(doumuProductInfo.getProductId(),"1");
        //保存附件
        List<DoumuProductFj> fjList = doumuProductInfo.getFjList();
        if(fjList!=null && fjList.size()>0){
            for (DoumuProductFj doumuProductFj : fjList) {
                //再保存附件
                doumuProductFj.setProductId(doumuProductInfo.getProductId());
                doumuProductFj.setModule("1");
                doumuProductFjMapper.insertDoumuProductFj(doumuProductFj);
            }
        }

        //将修改前的数据存入历史记录
        DoumuProductInfo productInfo = doumuProductInfoMapper.selectDoumuProductInfoByProductId(doumuProductInfo.getProductId());
        DoumuProductHistory doumuProductHistory = new DoumuProductHistory();
        ClassUtils.copyProperties(productInfo, doumuProductHistory);
        doumuProductHistoryMapper.insertDoumuProductHistory(doumuProductHistory);


        return doumuProductInfoMapper.updateDoumuProductInfo(doumuProductInfo);
    }





    /**
     * 批量删除痘姆古陶信息
     *
     * @param productIds 需要删除的痘姆古陶信息主键
     * @return 结果
     */
    @Override
    public int deleteDoumuProductInfoByProductIds(Long[] productIds)
    {
        return doumuProductInfoMapper.deleteDoumuProductInfoByProductIds(productIds);
    }

    /**
     * 删除痘姆古陶信息信息
     *
     * @param productId 痘姆古陶信息主键
     * @return 结果
     */
    @Override
    public int deleteDoumuProductInfoByProductId(Long productId)
    {
        return doumuProductInfoMapper.deleteDoumuProductInfoByProductId(productId);
    }

    /**
     * 批量修改流程
     *
     * @param doumuProductInfoVo 痘姆古陶信息VO
     * @return 结果
     */
    @Override
    public int editFlow(DoumuProductInfoVo doumuProductInfoVo) {
        if(doumuProductInfoVo.getProductIdList() == null || doumuProductInfoVo.getProductIdList().size()<=0){
            throw new ServiceException("请选择要修改的订单", HttpStatus.WARN);
        }
        List<Long> productIdList = doumuProductInfoVo.getProductIdList();
        String flowType = doumuProductInfoVo.getFlowType();
        return doumuProductInfoMapper.updateDoumuProductInfoFlowList(productIdList,flowType);
    }

    @Override
    public AjaxResult link(String dateType) {
        Map<String,Object> map = new HashMap<>();
        String startTime = DateUtils.getTime(dateType);
        String endTime = DateUtils.getTime("1");
        //查询时间内地数据
        SysDictData dictData = new SysDictData();
        dictData.setDictType("liuch");
        List<SysDictData> sysDictDataList = dictDataMapper.selectDictDataList(dictData);
        //计算总数
        DoumuProductInfo doumuProductInfo = new DoumuProductInfo();
        doumuProductInfo.setBeginTime(startTime);
        doumuProductInfo.setEndTime(endTime);
        List<DoumuProductInfo> doumuProductInfoList = doumuProductInfoMapper.selectDoumuProductInfoList(doumuProductInfo);
        if(doumuProductInfoList==null || doumuProductInfoList.size()<=0){
            map.put("all",0);
            for (SysDictData sysDictData : sysDictDataList) {
                map.put(sysDictData.getDictValue(),0);
            }
            return AjaxResult.success(map);
        }
        map.put("all",doumuProductInfoList.size());
        for (SysDictData sysDictData : sysDictDataList) {
            int num = 0;
            for (DoumuProductInfo productInfo : doumuProductInfoList) {
                if(sysDictData.getDictValue().equals(productInfo.getFlowType())){
                    num++;
                }
            }
            map.put(sysDictData.getDictValue(),num);
        }
        return AjaxResult.success(map);
    }

    @Override
    public AjaxResult monthLink() {
        Map<String,Object> map = new HashMap<>();
        String startTime = DateUtils.getTime("3");
        String endTime = DateUtils.getTime("1");
        //查询时间内地数据
        SysDictData dictData = new SysDictData();
        dictData.setDictType("liuch");
        List<SysDictData> sysDictDataList = dictDataMapper.selectDictDataList(dictData);
        //计算总数
        DoumuProductInfo doumuProductInfo = new DoumuProductInfo();
        doumuProductInfo.setBeginTime(startTime);
        doumuProductInfo.setEndTime(endTime);
        List<DoumuProductInfo> doumuProductInfoList = doumuProductInfoMapper.selectDoumuProductInfoList(doumuProductInfo);
        if(doumuProductInfoList==null || doumuProductInfoList.size()<=0){
            for (SysDictData sysDictData : sysDictDataList) {
                Map<String,Object> mapL = new HashMap<>();
                mapL.put("zs",0);
                mapL.put("lc",0);
                mapL.put("bfb","0%");
                map.put(sysDictData.getDictValue(),mapL);
            }
            return AjaxResult.success(map);
        }

        int count = doumuProductInfoList.size();
        BigDecimal num1 = new BigDecimal(count);
        for (SysDictData sysDictData : sysDictDataList) {

            Map<String,Object> mapL = new HashMap<>();
            int num = 0;
            for (DoumuProductInfo productInfo : doumuProductInfoList) {
                if(sysDictData.getDictValue().equals(productInfo.getFlowType())){
                    num++;
                }
            }
            mapL.put("zs",0);
            mapL.put("lc",0);
            mapL.put("bfb","0%");
            if(num != 0){
                BigDecimal num2 = new BigDecimal(num);
                double result = Double.parseDouble(((num2.divide(num1,2,BigDecimal.ROUND_HALF_UP))).toString());
                // 创建DecimalFormat对象并设置格式化模式为"0%"
                DecimalFormat decimalFormat = new DecimalFormat("0%");
                // 使用DecimalFormat对象进行格式化操作
                String percentage = decimalFormat.format((result));

                mapL.put("zs",num1.longValue());
                mapL.put("lc",num);
                mapL.put("bfb",percentage);
            }

            map.put(sysDictData.getDictValue(),mapL);

        }
        return AjaxResult.success(map);
    }

    @Override
    public AjaxResult numAmount() {
        Map<String,Object> map = new HashMap<>();
        //当前年第一天
        String startTime = DateUtils.getTime("5");
        //当天
        String endTime = DateUtils.getTime("1");
        //查询当前时间内数据
        DoumuProductInfo doumuProductInfo = new DoumuProductInfo();
        doumuProductInfo.setBeginTime(startTime);
        doumuProductInfo.setEndTime(endTime);
        List<DoumuProductInfo> doumuProductInfoList = doumuProductInfoMapper.selectDoumuProductInfoList(doumuProductInfo);
        List<String> listX = new ArrayList<>();
        //发货数
        List<String> listy1 = new ArrayList<>();
        //取货数
        List<String> listy2 = new ArrayList<>();
        //金额
        List<String> listy3 = new ArrayList<>();
        //获取当前年份
        String year = DateUtils.dateTimeNow("yyyy");
        if(doumuProductInfoList==null || doumuProductInfoList.size()<=0){
            for (int i = 1; i < 13; i++) {
                StringBuilder sb = new StringBuilder();
                sb.append(i).append("月");
                listX.add(sb.toString());
                listy1.add("0");
                listy2.add("0");
                listy3.add("0");
            }
            map.put("x",listX);
            map.put("y1",listy1);
            map.put("y2",listy2);
            map.put("y3",listy3);
            return AjaxResult.success(map);
        }
        for (int i = 1; i < 13; i++) {
            StringBuilder sb = new StringBuilder();
            sb.append(i).append("月");
            listX.add(sb.toString());

            //月份
            String month = year+"-0"+i;
            if(i>10){
                month = year+"-"+i;
            }
            //发货数
            int y1 = 0;
            //取货数
            int y2 = 0;
            //金额
            Double y3 = 0D;
            for (DoumuProductInfo productInfo : doumuProductInfoList) {
                if(productInfo.getCreateTime().toString().contains(month)){
                    //金额
                    BigDecimal num1 = new BigDecimal(y3);
                    BigDecimal num2 = new BigDecimal(productInfo.getTotalPrice());
                    BigDecimal subNum1 = num1.add(num2);
                    y3 = subNum1.doubleValue();
                    //邮寄
                    if("1".equals(productInfo.getDeliveryType())){
                        y1 = y1 + Integer.parseInt(productInfo.getQuantity());

                    }else {
                        //自取
                        y2 = y2 + Integer.parseInt(productInfo.getQuantity());
                    }

                }
            }
            listy1.add(String.valueOf(y1));
            listy2.add(String.valueOf(y2));
            listy3.add(String.valueOf(y3));

        }
        map.put("x",listX);
        map.put("y1",listy1);
        map.put("y2",listy2);
        map.put("y3",listy3);
        return AjaxResult.success(map);
    }

    @Override
    public AjaxResult weekFollow() {
        Map<String,Object> map = new HashMap<>();
        String startTime = DateUtils.getTime("2");
        String endTime = DateUtils.getTime("1");
        //时间内的订单
        DoumuEvaluate doumuEvaluate = new DoumuEvaluate();
        doumuEvaluate.setBeginTime(startTime);
        doumuEvaluate.setEndTime(endTime);
        List<DoumuEvaluate> doumuEvaluateList = doumuEvaluateMapper.selectDoumuEvaluateList(doumuEvaluate);
        //销售总金额
        Double xszje = 0D;
        //订单总数量
        int ddzs = 0;
        //订单好评数（非常好）
        int fch = 0;
        //订单好评数（好）
        int h = 0;
        if(doumuEvaluateList!=null && doumuEvaluateList.size()>0){
            ddzs = doumuEvaluateList.size();
            List<Long> productIdList = doumuEvaluateList.stream().map(DoumuEvaluate::getProductId).collect(Collectors.toList());
            for (DoumuEvaluate evaluate : doumuEvaluateList) {
                if("3".equals(evaluate.getSynthesisEvaluate())){
                    fch++;
                }
                if("2".equals(evaluate.getSynthesisEvaluate())){
                    h++;
                }
            }
            List<DoumuProductInfo> doumuProductInfoList = doumuProductInfoMapper.selectDoumuProductInfoByProductIdList(productIdList);
            for (DoumuProductInfo doumuProductInfo : doumuProductInfoList) {
                //金额
                BigDecimal num1 = new BigDecimal(xszje);
                BigDecimal num2 = new BigDecimal(doumuProductInfo.getTotalPrice());
                BigDecimal subNum1 = num1.add(num2);
                xszje = subNum1.doubleValue();
            }

        }
        map.put("xszje",xszje);
        map.put("ddzs",ddzs);
        map.put("fch",fch);
        map.put("h",h);
        return AjaxResult.success(map);
    }

    @Override
    public AjaxResult evaluate() {
        Map<String,Object> map = new HashMap<>();
        List<DoumuEvaluate> doumuEvaluateList = doumuEvaluateMapper.selectDoumuEvaluateList(new DoumuEvaluate());
        //非常好
        int fch = 0;
        //好
        int h = 0;
        //一般
        int yb = 0;
        //差
        int c = 0;
        //很差
        int hc = 0;
        if(doumuEvaluateList!=null && doumuEvaluateList.size()>0){
            for (DoumuEvaluate evaluate : doumuEvaluateList) {
                if("5".equals(evaluate.getProductEvaluate())){
                    fch++;
                }else if("4".equals(evaluate.getProductEvaluate())){
                    h++;
                }else if("3".equals(evaluate.getProductEvaluate())){
                    yb++;
                }else if("2".equals(evaluate.getProductEvaluate())){
                    c++;
                }else if("1".equals(evaluate.getProductEvaluate())){
                    hc++;
                }
            }
        }
        map.put("fch",fch);
        map.put("h",h);
        map.put("yb",yb);
        map.put("c",c);
        map.put("hc",hc);
        return AjaxResult.success(map);
    }

    @Override
    public AjaxResult sales() {
        Map<String,Object> map = new HashMap<>();
        //当前年第一天
        String startTime = DateUtils.getTime("5");
        //当天
        String endTime = DateUtils.getTime("1");
        //查询当前时间内数据
        DoumuProductInfo doumuProductInfo = new DoumuProductInfo();
        doumuProductInfo.setBeginTime(startTime);
        doumuProductInfo.setEndTime(endTime);
        List<DoumuProductInfo> doumuProductInfoList = doumuProductInfoMapper.selectDoumuProductInfoList(doumuProductInfo);
        //月份
        List<String> listX = new ArrayList<>();
        //金额
        List<String> listy = new ArrayList<>();
        //获取当前年份
        String year = DateUtils.dateTimeNow("yyyy");
        if(doumuProductInfoList==null || doumuProductInfoList.size()<=0){
            for (int i = 1; i < 13; i++) {
                StringBuilder sb = new StringBuilder();
                sb.append(i).append("月");
                listX.add(sb.toString());
                listy.add("0");
            }
            map.put("month",listX);
            map.put("sales",listy);
            return AjaxResult.success(map);
        }
        String nowMonth = DateUtils.dateTimeNow("yyyy-MM");
        map.put("nowMonth","0");
        for (int i = 1; i < 13; i++) {
            StringBuilder sb = new StringBuilder();
            sb.append(i).append("月");
            listX.add(sb.toString());
            //月份
            String month = year+"-0"+i;
            if(i>10){
                month = year+"-"+i;
            }
            //金额
            Double y3 = 0D;
            for (DoumuProductInfo productInfo : doumuProductInfoList) {
                if(productInfo.getCreateTime().toString().contains(month)){
                    //金额
                    BigDecimal num1 = new BigDecimal(y3);
                    BigDecimal num2 = new BigDecimal(productInfo.getTotalPrice());
                    BigDecimal subNum1 = num1.add(num2);
                    y3 = subNum1.doubleValue();
                }
            }
            if(nowMonth.equals(month)){
                map.put("nowMonth",String.valueOf(y3));
            }
            listy.add(String.valueOf(y3));

        }
        map.put("month",listX);
        map.put("sales",listy);
        return AjaxResult.success(map);
    }

    @Override
    public AjaxResult numberWorks() {
        Map<String,Object> map = new HashMap<>();
        //当前年第一天
        String startTime = DateUtils.getTime("5");
        //当天
        String endTime = DateUtils.getTime("1");
        //查询当前时间内数据
        DoumuProductInfo doumuProductInfo = new DoumuProductInfo();
        doumuProductInfo.setBeginTime(startTime);
        doumuProductInfo.setEndTime(endTime);
        List<DoumuProductInfo> doumuProductInfoList = doumuProductInfoMapper.selectDoumuProductInfoList(doumuProductInfo);
        List<String> listX = new ArrayList<>();
        //发货数
        List<String> listy = new ArrayList<>();

        //获取当前年份
        String year = DateUtils.dateTimeNow("yyyy");
        if(doumuProductInfoList==null || doumuProductInfoList.size()<=0){
            for (int i = 1; i < 13; i++) {
                StringBuilder sb = new StringBuilder();
                sb.append(i).append("月");
                listX.add(sb.toString());
                listy.add("0");

            }
            map.put("totality",0);
            map.put("month",listX);
            map.put("num",listy);
            return AjaxResult.success(map);
        }
        int totality = 0;
        for (int i = 1; i < 13; i++) {
            StringBuilder sb = new StringBuilder();
            sb.append(i).append("月");
            listX.add(sb.toString());

            //月份
            String month = year+"-0"+i;
            if(i>10){
                month = year+"-"+i;
            }
            //发货数
            int y = 0;

            for (DoumuProductInfo productInfo : doumuProductInfoList) {
                if(productInfo.getCreateTime().toString().contains(month)){
                    y = y + Integer.parseInt(productInfo.getQuantity());
                }
            }
            totality = totality + y;
            listy.add(String.valueOf(y));
        }
        map.put("totality",totality);
        map.put("month",listX);
        map.put("num",listy);
        return AjaxResult.success(map);
    }


    /**
     * app首页好评率统计
     * dateType 1：当天，2：本周，3：本月，4：当前季度，5：年度
     */
    @Override
    public AjaxResult reputation(String dateType) {
        Map<String,Object> map = new HashMap<>();
        String startTime = DateUtils.getTime(dateType);
        String endTime = DateUtils.getTime("1");
        DoumuEvaluate doumuEvaluate = new DoumuEvaluate();
        doumuEvaluate.setBeginTime(startTime);
        doumuEvaluate.setEndTime(endTime);
        List<DoumuEvaluate> doumuEvaluateList = doumuEvaluateMapper.selectDoumuEvaluateList(doumuEvaluate);
        if(doumuEvaluateList==null || doumuEvaluateList.size()<=0){
            map.put("fch",0);
            map.put("h",0);
            map.put("yb",0);
            map.put("c",0);
            map.put("hc",0);
            return AjaxResult.success(map);
        }
        int zs = doumuEvaluateList.size();
        BigDecimal numZs = new BigDecimal(zs);
        //非常好
        int fch = 0;
        //好
        int h = 0;
        //一般
        int yb = 0;
        //差
        int c = 0;
        //很差
        int hc = 0;
        if(doumuEvaluateList!=null && doumuEvaluateList.size()>0){
            for (DoumuEvaluate evaluate : doumuEvaluateList) {
                if("5".equals(evaluate.getProductEvaluate())){
                    fch++;
                }else if("4".equals(evaluate.getProductEvaluate())){
                    h++;
                }else if("3".equals(evaluate.getProductEvaluate())){
                    yb++;
                }else if("2".equals(evaluate.getProductEvaluate())){
                    c++;
                }else if("1".equals(evaluate.getProductEvaluate())){
                    hc++;
                }
            }
            map.put("fch",fch);
            map.put("h",h);
            map.put("yb",yb);
            map.put("c",c);
            map.put("hc",hc);

        }
        return AjaxResult.success(map);
    }
}
