package com.ruoyi.system.service.impl;


import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.http.HttpUtils;
import com.ruoyi.common.utils.sign.Base64;
import com.ruoyi.system.domain.DoumuProductInfo;
import com.ruoyi.system.domain.wx.*;
import com.ruoyi.system.mapper.DoumuProductInfoMapper;
import com.ruoyi.system.service.IWxPayService;
import com.wechat.pay.java.core.Config;
import com.wechat.pay.java.core.RSAAutoCertificateConfig;
import com.wechat.pay.java.core.notification.NotificationConfig;
import com.wechat.pay.java.core.notification.NotificationParser;
import com.wechat.pay.java.core.notification.RequestParam;
import com.wechat.pay.java.service.partnerpayments.jsapi.model.Transaction;
import com.wechat.pay.java.service.payments.jsapi.JsapiService;
import com.wechat.pay.java.service.payments.jsapi.model.Amount;
import com.wechat.pay.java.service.payments.jsapi.model.Payer;
import com.wechat.pay.java.service.payments.jsapi.model.PrepayRequest;
import com.wechat.pay.java.service.payments.jsapi.model.PrepayResponse;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.omg.CORBA.TIMEOUT;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Configurable;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import utils.AppletDecryptDataUtil;
import utils.HttpClientUtils;
import utils.WxPayUtil;

import javax.annotation.Resource;
import javax.servlet.ServletInputStream;
import javax.servlet.http.HttpServletRequest;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import static com.wechat.pay.java.core.http.Constant.*;

/**
 * @Author: tjf
 * @Date: 2024/1/17 14:16
 * @Describe:
 */
@Service
public class WxPayServiceImpl implements IWxPayService {

    private final String JSCODE_SESSION_API = "https://api.weixin.qq.com/sns/jscode2session?appid=APPID&secret=SECRET&js_code=JSCODE&grant_type=authorization_code";
    //获取微信AccessToken接口地址实例勿改
    private static final String ACCESS_TOKEN = "https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid=APPID&secret=APPSECRET";
    //文本内容安全识别
    private static final String MSGSECCHECK = "https://api.weixin.qq.com/wxa/msg_sec_check?access_token=ACCESS_TOKEN";
    //公众号发送模板消息
    private static final String TEMPLATE_MESSAGE = "https://api.weixin.qq.com/cgi-bin/message/template/send?access_token=ACCESS_TOKEN";


    @Autowired
    private DoumuProductInfoMapper doumuProductInfoMapper;
    /**
     * 小程序appId
     */
    @Value("${wx.app-id}")
    private String appId;

    /**
     * 小程序密钥
     */
    @Value("${wx.app-secret}")
    private String appSecret;

    @Resource
    private WxPayV3Bean wxPayV3Bean;

    @Resource
    private RedisCache redisCache;

    /**
     * 创建微信预支付订单
     *
     * @param req
     * @return
     */
    @Override
    public AjaxResult createOrder(WxPayOrderReqVo req) throws Exception {
        try {
            // 使用自动更新平台证书的RSA配置
            // 一个商户号只能初始化一个配置，否则会因为重复的下载任务报错
            Config config =
                    new RSAAutoCertificateConfig.Builder()
                            .merchantId(wxPayV3Bean.getMchId())
                            .privateKeyFromPath(wxPayV3Bean.getKeyPath())
                            .merchantSerialNumber(wxPayV3Bean.getMchSerialNo())
                            .apiV3Key(wxPayV3Bean.getApiKey())
                            .build();
            // 构建service
            JsapiService service = new JsapiService.Builder().config(config).build();
            // request.setXxx(val)设置所需参数，具体参数可见Request定义
            PrepayRequest request = new PrepayRequest();
            Amount amount = new Amount();
            //元转分
            amount.setTotal((req.getTotalPrice().multiply(new BigDecimal(100))).intValue());
            request.setAmount(amount);
            request.setAppid(wxPayV3Bean.getAppId());
            request.setMchid(wxPayV3Bean.getMchId());
            request.setDescription(req.getGoodsName());
            request.setNotifyUrl(wxPayV3Bean.getNotifyUrl());
            request.setOutTradeNo(req.getOrderSn());
            //自定义数据设置为商品名称
            request.setAttach(req.getGoodsName());
            Payer payer = new Payer();
            payer.setOpenid(req.getOpenId());
            request.setPayer(payer);
            // 调用下单方法，得到应答
            PrepayResponse response = service.prepay(request);
            WxPayRespVo vo = new WxPayRespVo();
            Long timeStamp = System.currentTimeMillis() / 1000;
            vo.setTimeStamp(timeStamp.toString());
            String substring = UUID.randomUUID().toString().replaceAll("-", "").substring(0, 32);
            vo.setNonceStr(substring);
            String signatureStr = Stream.of(wxPayV3Bean.getAppId(), String.valueOf(timeStamp), substring, "prepay_id=" + response.getPrepayId())
                    .collect(Collectors.joining("\n", "", "\n"));
            String sign = WxPayUtil.getSign(signatureStr, wxPayV3Bean.getKeyPath());
            vo.setPaySign(sign);
            vo.setPrepayId("prepay_id="+response.getPrepayId());
            vo.setAppId(wxPayV3Bean.getAppId());
            vo.setSignType("RSA");
            //TemplateMessageZhiFu(req,request);
            //todo 存储预支付订单信息
            return AjaxResult.success(vo);
        } catch (ServiceException e) {
            System.out.println("创建微信预支付订单失败");

        }
        return AjaxResult.error();
    }

    /**
     * 微信支付回调
     *
     * @param request
     * @return
     */
    @Override
    public void payNotify(HttpServletRequest request) {
        /**
         * {
         *     "id": "EV-2018022511223320873",
         *     "create_time": "2015-05-20T13:29:35+08:00",
         *     "resource_type": "encrypt-resource",
         *     "event_type": "TRANSACTION.SUCCESS",
         *     "summary": "支付成功",
         *     "resource": {
         *         "original_type": "transaction",
         *         "algorithm": "AEAD_AES_256_GCM",
         *         "ciphertext": "",
         *         "associated_data": "",
         *         "nonce": ""
         *     }
         * }
         */
        try {
            //读取请求体的信息
            ServletInputStream inputStream = request.getInputStream();
            StringBuffer stringBuffer = new StringBuffer();
            BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(inputStream));
            String s;
            //读取回调请求体
            while ((s = bufferedReader.readLine()) != null) {
                stringBuffer.append(s);
            }
            String s1 = stringBuffer.toString();
            String timestamp = request.getHeader(WECHAT_PAY_TIMESTAMP);
            String nonce = request.getHeader(WECHAT_PAY_NONCE);
            String signType = request.getHeader("Wechatpay-Signature-Type");
            String serialNo = request.getHeader(WECHAT_PAY_SERIAL);
            String signature = request.getHeader(WECHAT_PAY_SIGNATURE);
            // 如果已经初始化了 RSAAutoCertificateConfig，可直接使用
            // 没有的话，则构造一个
            // log.error(com.alibaba.fastjson2.JSON.toJSONString(wxPayV3Bean));
            NotificationConfig config = new RSAAutoCertificateConfig.Builder()
                    .merchantId(wxPayV3Bean.getMchId())
                    .privateKeyFromPath(wxPayV3Bean.getKeyPath())
                    .merchantSerialNumber(wxPayV3Bean.getMchSerialNo())
                    .apiV3Key(wxPayV3Bean.getApiKey())
                    .build();
            // 初始化 NotificationParser
            NotificationParser parser = new NotificationParser(config);
            RequestParam requestParam = new RequestParam.Builder()
                    .serialNumber(serialNo)
                    .nonce(nonce)
                    .signature(signature)
                    .timestamp(timestamp)
                    // 若未设置signType，默认值为 WECHATPAY2-SHA256-RSA2048
                    .signType(signType)
                    .body(s1)
                    .build();
            Transaction parse = parser.parse(requestParam, Transaction.class);
            /**
             * trade_state
             * 必填
             * string(32)
             * 交易状态，枚举值：
             * SUCCESS：支付成功
             * REFUND：转入退款
             * NOTPAY：未支付
             * CLOSED：已关闭
             * REVOKED：已撤销（付款码支付）
             * USERPAYING：用户支付中（付款码支付）
             * PAYERROR：支付失败(其他原因，如银行返回失败)
             */
            //todo 存储支付结果 支付成功需要修改订单状态
            Transaction.TradeStateEnum tradeState = parse.getTradeState();
            if (Transaction.TradeStateEnum.SUCCESS.equals(tradeState)){
                String outTradeNo = parse.getOutTradeNo();
                //订单支付成功
                DoumuProductInfo doumuProductInfo = new DoumuProductInfo();
                doumuProductInfo.setOrderNumber(outTradeNo);
                doumuProductInfo.setStatus("2");
                doumuProductInfoMapper.updateDoumuProductInfo(doumuProductInfo);
            }
            TemplateMessage(parse);
            System.out.println("parse = " + parse);
        } catch (Exception e) {
            System.out.println("获取微信支付回调失败");
        }
    }

    /**
     *   给微信公共号下发消息
     */
    @Override
    public void TemplateMessage(Transaction parse ) {
        /**
         * {
         *            "touser":"OPENID",
         *            "template_id":"ngqIpbwh8bUfcSsECmogfXcV14J0tQlEpBO27izEYtY",
         *            "url":"http://weixin.qq.com/download",
         *            "miniprogram":{
         *              "appid":"xiaochengxuappid12345",
         *              "pagepath":"index?foo=bar"
         *            },
         *            "client_msg_id":"MSG_000001",
         *            "data":{
         *
         *                    "keyword1":{
         *                        "value":"巧克力"
         *                    },
         *                    "keyword2": {
         *                        "value":"39.8元"
         *                    },
         *                    "keyword3": {
         *                        "value":"2014年9月22日"
         *                    }
         *            }
         *        }
         */
        Object accessToken = null;
        try {
            //todo 需要根据公众号的appid和秘钥获取token
            //公众号appid:wxb581c5d48ffa6327
            //从redis中获取
            accessToken = redisCache.getCacheObject(Constants.WX_ACCESS_TOKEN);
            if (ObjectUtils.isEmpty(accessToken)) {
                String result = HttpClientUtils.doGet(ACCESS_TOKEN.replace("APPID", appId)
                        .replace("APPSECRET", appSecret)
                );
                JSONObject jsonObject = JSONObject.parseObject(result);
                accessToken = jsonObject.get("access_token");
                redisCache.setCacheObject(Constants.WX_ACCESS_TOKEN, accessToken, Constants.CAPTCHA_EXPIRATION, TimeUnit.HOURS);
            }
            JSONObject jsonObject = new JSONObject();
            JSONObject jsonObjectData = new JSONObject();
            //接收者openid sp_openid 用户在服务商应用下的用户标示 sub_appid 子商户应用载体的AppID,
            jsonObject.put("touser", parse.getPayer().getSpOpenid());
            //模板ID
            jsonObject.put("template_id", "rtYn3Mjepo8TSeCwabgbln3TEiWXYcfPQmAiFP9V5PU");
            //所需跳转到的小程序appid（该小程序appid必须与发模板消息的公众号是绑定关联关系，暂不支持小游戏）
            jsonObject.put("appid", appId);
            /**
             * {{first.DATA}}
             * 订单编号：{{keyword1.DATA}}
             * 商品名称：{{keyword2.DATA}}
             * 订单总价：{{keyword3.DATA}}
             * 订单状态：{{keyword4.DATA}}
             * 下单时间：{{keyword5.DATA}}
             * {{remark.DATA}}
             */
            jsonObjectData.put("first","恭喜您！购买的商品已支付成功。");
            jsonObjectData.put("keyword1",parse.getOutTradeNo());
            jsonObjectData.put("keyword2",parse.getAttach());
            jsonObjectData.put("keyword3",parse.getAmount());
            jsonObjectData.put("keyword4",parse.getTradeStateDesc());
            jsonObjectData.put("keyword5",parse.getOutTradeNo());
            jsonObjectData.put("remark","欢迎您的到来！");
            //模板数据
            jsonObject.put("data", jsonObjectData);
            String msgsecCheck = HttpUtil.post(TEMPLATE_MESSAGE.replace("ACCESS_TOKEN", (String) accessToken), jsonObject.toJSONString());
            System.out.println("消息模板通知结果:"+msgsecCheck);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     *   给微信公共号下发消息预支付测试
     */
    public void TemplateMessageZhiFu(WxPayOrderReqVo req,PrepayRequest request ) {
        /**
         * {
         *            "touser":"OPENID",
         *            "template_id":"ngqIpbwh8bUfcSsECmogfXcV14J0tQlEpBO27izEYtY",
         *            "url":"http://weixin.qq.com/download",
         *            "miniprogram":{
         *              "appid":"xiaochengxuappid12345",
         *              "pagepath":"index?foo=bar"
         *            },
         *            "client_msg_id":"MSG_000001",
         *            "data":{
         *
         *                    "keyword1":{
         *                        "value":"巧克力"
         *                    },
         *                    "keyword2": {
         *                        "value":"39.8元"
         *                    },
         *                    "keyword3": {
         *                        "value":"2014年9月22日"
         *                    }
         *            }
         *        }
         */
        Object accessToken = null;
        try {
            //从redis中获取
            accessToken = redisCache.getCacheObject(Constants.WX_ACCESS_TOKEN);
            if (ObjectUtils.isEmpty(accessToken)) {
                String result = HttpClientUtils.doGet(ACCESS_TOKEN.replace("APPID", appId)
                        .replace("APPSECRET", appSecret)
                );
                JSONObject jsonObject = JSONObject.parseObject(result);
                accessToken = jsonObject.get("access_token");
                redisCache.setCacheObject(Constants.WX_ACCESS_TOKEN, accessToken, Constants.CAPTCHA_EXPIRATION, TimeUnit.HOURS);
            }
            JSONObject jsonObject = new JSONObject();
            JSONObject jsonObjectData = new JSONObject();
            //接收者openid sp_openid 用户在服务商应用下的用户标示 sub_appid 子商户应用载体的AppID,
            jsonObject.put("touser", req.getOpenId());
            //模板ID
            jsonObject.put("template_id", "rtYn3Mjepo8TSeCwabgbln3TEiWXYcfPQmAiFP9V5PU");
            //所需跳转到的小程序appid（该小程序appid必须与发模板消息的公众号是绑定关联关系，暂不支持小游戏）
            jsonObject.put("appid", appId);
            /**
             * {{first.DATA}}
             * 订单编号：{{keyword1.DATA}}
             * 商品名称：{{keyword2.DATA}}
             * 订单总价：{{keyword3.DATA}}
             * 订单状态：{{keyword4.DATA}}
             * 下单时间：{{keyword5.DATA}}
             * {{remark.DATA}}
             */
            jsonObjectData.put("first","恭喜您！购买的商品等待支付。");
            jsonObjectData.put("keyword1",request.getOutTradeNo());
            jsonObjectData.put("keyword2",request.getAttach());
            jsonObjectData.put("keyword3",request.getAmount());
            jsonObjectData.put("keyword4","待支付");
            jsonObjectData.put("keyword5",request.getOutTradeNo());
            jsonObjectData.put("remark","欢迎您的到来！");
            //模板数据
            jsonObject.put("data", jsonObjectData);
            String msgsecCheck = HttpUtil.post(TEMPLATE_MESSAGE.replace("ACCESS_TOKEN", (String) accessToken), jsonObject.toJSONString());
            System.out.println("消息模板通知结果:"+msgsecCheck);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    /**
     * 根据code获取小程序openid和unionid
     *
     * @param form
     * @return
     */
    @Override
    public AppletSessionDTO jscode2Session(AppletLoginForm form) {
        // 获取openId和sessionKey
        JSONObject result;
        try {
            String requestUrl = JSCODE_SESSION_API.replace("APPID", appId)
                    .replace("SECRET", appSecret)
                    .replace("JSCODE", form.getCode().trim());

            String jsonStr = HttpClientUtils.doGet(requestUrl);
            result = JSONObject.parseObject(jsonStr);
            if (StringUtils.isEmpty(result.toString())) {
                throw new RuntimeException("错误");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("错误");
        }

        int errcode = result.getIntValue("errcode");
        if (errcode != 0) {
            String errmsg = result.getString("errmsg");
            throw new RuntimeException("获取小程序授权错误信息, " + errmsg);
        }
        // 获取openId,unionId,sessionKey
        AppletSessionDTO appletSession = new AppletSessionDTO();
        appletSession.setOpenId(result.getString("openid"));
        // unionId有可能是空
        appletSession.setUnionId(result.getString("unionid"));
        appletSession.setSessionKey(result.getString("session_key"));
        String phoneNumber = getPhoneNumber(form, appletSession);
        appletSession.setPhoneNumber(phoneNumber);
        return appletSession;
    }

    /**
     * 根获取微信文本内容安全识别
     *
     * @return
     */
    @Override
    public AjaxResult msgSecCheck(AppletSessionDTO dto) {
        Object accessToken = null;
        try {
            //从redis中获取
            accessToken = redisCache.getCacheObject(Constants.WX_ACCESS_TOKEN);
            if (ObjectUtils.isEmpty(accessToken)) {
                String result = HttpClientUtils.doGet(ACCESS_TOKEN.replace("APPID", appId)
                        .replace("APPSECRET", appSecret)
                );
                JSONObject jsonObject = JSONObject.parseObject(result);
                accessToken = jsonObject.get("access_token");
                redisCache.setCacheObject(Constants.WX_ACCESS_TOKEN, accessToken, Constants.CAPTCHA_EXPIRATION, TimeUnit.HOURS);
            }
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("content", dto.getContent());
            jsonObject.put("version", 2);
            jsonObject.put("openid", dto.getOpenId());
            jsonObject.put("scene", 2);
            String msgsecCheck = HttpUtil.post(MSGSECCHECK.replace("ACCESS_TOKEN", (String) accessToken), jsonObject.toJSONString());
            JSONObject msgsecCheckResult = JSONObject.parseObject(msgsecCheck);
            JSONObject result = (JSONObject) msgsecCheckResult.get("result");
            Integer label = (Integer) result.get("label");
            if (label != 100) {
                return AjaxResult.error("含有违规信息");
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        return AjaxResult.success();
    }

    /**
     * 手机号解密
     */
    private static String getPhoneNumber(AppletLoginForm form, AppletSessionDTO appletSession) {

        // 解密文件
        String encryptedData = form.getEncryptedData();
        // 解密向量
        String iv = form.getIv();
        // 加密秘钥
        byte[] dataByte = Base64.decode(encryptedData);
        // session_key
        byte[] keyByte = Base64.decode(appletSession.getSessionKey());
        // 偏移量
        byte[] ivByte = Base64.decode(iv);
        JSONObject result;
        try {
            result = AppletDecryptDataUtil.decryptData(keyByte, ivByte, dataByte);
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }

        assert result != null;
        String purePhoneNumber = result.getString("purePhoneNumber");
        if (null == purePhoneNumber || purePhoneNumber.isEmpty()) {
            throw new RuntimeException("获取手机号失败");
        }
        return purePhoneNumber;
    }
}
